@@ -7,12 +7,12 @@ from selenium.common.exceptions import NoSuchElementException
 import pyperclip
 import time
 
-def sendmsg(usr, msg, path='error', attach='error', followupmsg='error'):
+def sendmsg(usr, msg, path='error', attach='error'):
     
     CHROME_PROFILE_PATH = "user-data-dir=C:\\Users\\HP\\AppData\\Local\\Google\\Chrome\\User Data\\Login"
     users = "error"
     mssg = "error"
-    followupmssg = "error"
+    # followupmssg = "error"
 
     try:
         if usr:
@@ -28,9 +28,9 @@ def sendmsg(usr, msg, path='error', attach='error', followupmsg='error'):
     except IndexError:
         print("Please Provide The Message File as 2st Argument")
 
-    if followupmsg != 'error':
-        with open(followupmsg, 'r', encoding='utf8') as file:
-                followupmssg = file.read()
+    # if followupmsg != 'error':
+    #     with open(followupmsg, 'r', encoding='utf8') as file:
+    #             followupmssg = file.read()
 
     options = webdriver.ChromeOptions()
     options.add_argument(CHROME_PROFILE_PATH)
@@ -79,19 +79,19 @@ def sendmsg(usr, msg, path='error', attach='error', followupmsg='error'):
                     text_box.send_keys(Keys.SHIFT, Keys.INSERT)
                     text_box.send_keys(Keys.ENTER)
                     time.sleep(1)
-                elif followupmsg != 'error':
-                    msgbox_xpath = '//div[@title="Type a message"][@role="textbox"]'
-                    msgbox = browser.find_element('xpath', msgbox_xpath)
-                    pyperclip.copy(mssg)
-                    msgbox.send_keys(Keys.SHIFT, Keys.INSERT)
-                    time.sleep(2)
-                    msgbox.send_keys(Keys.ENTER)
-                    time.sleep(1)
-                    pyperclip.copy(followupmssg)
-                    msgbox.send_keys(Keys.SHIFT, Keys.INSERT)
-                    time.sleep(2)
-                    msgbox.send_keys(Keys.ENTER)
-                    time.sleep(1)
+                # elif followupmsg != 'error':
+                #     msgbox_xpath = '//div[@title="Type a message"][@role="textbox"]'
+                #     msgbox = browser.find_element('xpath', msgbox_xpath)
+                #     pyperclip.copy(mssg)
+                #     msgbox.send_keys(Keys.SHIFT, Keys.INSERT)
+                #     time.sleep(2)
+                #     msgbox.send_keys(Keys.ENTER)
+                #     time.sleep(1)
+                #     pyperclip.copy(followupmssg)
+                #     msgbox.send_keys(Keys.SHIFT, Keys.INSERT)
+                #     time.sleep(2)
+                #     msgbox.send_keys(Keys.ENTER)
+                #     time.sleep(1)
                 else:
                     msgbox_xpath = '//div[@title="Type a message"][@role="textbox"]'
                     msgbox = browser.find_element('xpath', msgbox_xpath)
